@@ -1,12 +1,11 @@
 package Dist::Inkt::Role::ProcessDOAP;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.101_02';
+our $VERSION   = '0.016';
 
 use Moose::Role;
-use List::Util 'uniq';
+use List::MoreUtils 'uniq';
 use namespace::autoclean;
-use URI;
 
 with 'Dist::Inkt::Role::RDFModel';
 
@@ -139,35 +138,20 @@ sub cpanmeta_resources
 		}
 	}
 	
-	($resources{x_mailinglist}) =
+	($resources{X_mailinglist}) =
 		map  { $_->uri }
 		grep defined,
 		$self->doap_project->mailing_list;
 	
-	($resources{x_wiki}) =
+	($resources{X_wiki}) =
 		map  { $_->uri }
 		grep defined,
 		$self->doap_project->wiki;
-	
-	($resources{x_identifier}) =
+
+	($resources{X_identifier}) =
 		map  { $_->uri }
 		grep defined,
 		$self->doap_project->rdf_about;
-	
-	($resources{x_IRC}) =
-		map  { $_->uri }
-		grep defined,
-		$self->model->objects(RDF::Trine::iri($self->project_uri), $CPAN->x_IRC);
-
-	if (defined($self->doap_project->support_forum)) {
-	  foreach my $forum (@{ $self->doap_project->support_forum }) {
-		 my $forumuri = URI->new($forum->uri);
-		 if ($forumuri->scheme =~ m/^ircs?$/) {
-			$resources{x_IRC} = $forumuri->as_string;
-			last;
-		 }
-	  }
-	}
 
 	delete $resources{$_} for grep !defined $resources{$_}, keys %resources;
 	
