@@ -1,7 +1,7 @@
 package Dist::Inkt::Role::ProcessDOAPDeps;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.101_02';
+our $VERSION   = '0.016';
 
 use Moose::Role;
 use namespace::autoclean;
@@ -120,9 +120,9 @@ sub doap_deps
 					no warnings;
 					$Reqs->add_string_requirement($mod => $ver);
 					
-					if ($phase eq 'runtime' and $level eq 'conflict')
+					if ($phase eq 'runtime' and $level eq 'conflict' and $ver =~ m{\A<= (v?[0-9_.]+)\z})
 					{
-						$meta->{x_breaks}{$mod} = $ver;
+						$meta->{x_breaks}{$mod} = $1;
 					}
 				}
 			}
