@@ -1,7 +1,7 @@
 package Dist::Inkt::Role::WriteCREDITS;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.101_02';
+our $VERSION   = '0.016';
 
 use Moose::Role;
 use namespace::autoclean;
@@ -42,7 +42,7 @@ sub Build_CREDITS
 		(my $method = "gather_all_${role}s") =~ s/ss$/s/s;
 		my @peeps =
 			sort { $a->to_string cmp $b->to_string }
-			grep { blessed($_) and not $already{$_}++ }
+			grep { not $already{$_}++ }
 			$self->doap_project->$method;
 		next unless @peeps;
 		
