@@ -1,9 +1,10 @@
 package Dist::Inkt::Role::WriteChanges;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.101_02';
+our $VERSION   = '0.016';
 
 use Moose::Role;
+use RDF::DOAP::ChangeSets;
 use namespace::autoclean;
 
 with 'Dist::Inkt::Role::RDFModel';
